# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import deep_lynx
from deep_lynx.api.tasks_api import TasksApi  # noqa: E501
from deep_lynx.rest import ApiException


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_containers_container_id_task(self):
        """Test case for get_containers_container_id_task

        List Tasks  # noqa: E501
        """
        pass

    def test_get_containers_container_id_task_task_id(self):
        """Test case for get_containers_container_id_task_task_id

        Get Task  # noqa: E501
        """
        pass

    def test_post_containers_container_id_task(self):
        """Test case for post_containers_container_id_task

        Create Task  # noqa: E501
        """
        pass

    def test_put_containers_container_id_task_task_id(self):
        """Test case for put_containers_container_id_task_task_id

        Update Task  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
